@@ -275,7 +275,7 @@ class GetFilesThreaded:
             # pylint: disable=unused-variable
             for root, folders, files in os.walk(path):
 
-                print(f"Active Threads: {csu.format.left_pad(len(self.threads),3,'0')} Total Files: {len(self.file_array)}", end="\r", flush=True)
+                # print(f"Active Threads: {csu.format.left_pad(len(self.threads),3,'0')} Total Files: {len(self.file_array)}", end="\r", flush=True)
                 while len(self.threads) >= self.max_threads:
                     time.sleep(.1)
 
@@ -293,7 +293,7 @@ class GetFilesThreaded:
             # return self.file_array
             # path_files = index_files(path, extension_array, ignore_array, recursive)
             # file_array = path_files + file_array
-        print(f"                                                                                                                      ", end="\r", flush=True)
+        # print(f"                                                                                                                      ", end="\r", flush=True)
         return self.file_array
 
         # def _get_files_single_thread(search_path=False, recursive=False, exclude=None, include=None, extensions=None, data_include=None):
