@@ -808,8 +808,12 @@ def gen_relative_path(src_base, dst_base, file_path):
         `author`: Colemen Atwood
         `created`: 12-17-2021 16:14:55
         `memberOf`: file
-        `version`: 1.0
+        `version`: 1.1
         `method_name`: gen_relative_path
+
+        Changes
+        ----------
+        12\\17\\2021 17:11:09 -If no path is provided, the file name is returned.
     '''
     src_base = strUtils.format.file_path(src_base)
     dst_base = strUtils.format.file_path(dst_base)
@@ -848,6 +852,9 @@ def gen_relative_path(src_base, dst_base, file_path):
     if relative_path is not None:
         relative_path = relative_path.replace(dst_base, "")
         relative_path = relative_path.replace(src_base, "")
+    if relative_path is None:
+        relative_path = os.path.basename(file_path)
+        # print(f"boobs: {relative_path}")
     return relative_path
 
 
@@ -886,8 +893,11 @@ def gen_dst_path(src_base, dst_base, file_path):
         `version`: 1.0
         `method_name`: gen_dst_path
     '''
-
+    src_base = strUtils.format.file_path(src_base)
+    dst_base = strUtils.format.file_path(dst_base)
+    file_path = strUtils.format.file_path(file_path)
     if src_base not in file_path and dst_base not in file_path:
+        # print(f"tatertots")
         return strUtils.format.file_path(f"{dst_base}/{file_path}")
     relative_path = gen_relative_path(src_base, dst_base, file_path)
     return strUtils.format.file_path(f"{dst_base}/{relative_path}")
@@ -928,6 +938,9 @@ def gen_src_path(src_base, dst_base, file_path):
         `version`: 1.0
         `method_name`: gen_dst_path
     '''
+    src_base = strUtils.format.file_path(src_base)
+    dst_base = strUtils.format.file_path(dst_base)
+    file_path = strUtils.format.file_path(file_path)
     if src_base not in file_path and dst_base not in file_path:
         return strUtils.format.file_path(f"{src_base}/{file_path}")
     relative_path = gen_relative_path(src_base, dst_base, file_path)
@@ -943,6 +956,10 @@ def gen_src_path(src_base, dst_base, file_path):
 # get_data(file)
 
 
-# src = r"Z:\Structure\Archive\Images\Personal\Other\desktop.ini"
-# dst = r"X:\Structure\Archive\Images\Personal\Other\desktop.ini"
+# src = r"C:/Users/Colemen/Desktop/TEST_FOLDER/Mnemosyne Tests/sourceDirectory/rendering"
+# dst = r"/mnemosyne_sync_test"
+# file_path = r"C:\Users\Colemen\Desktop\TEST_FOLDER\Mnemosyne Tests\sourceDirectory\rendering\20211029151612812.jpg"
+# print(gen_relative_path(src, dst, file_path))
+# print("destination path: ", gen_dst_path(src, dst, file_path))
+# print("source path: ", gen_src_path(src, dst, file_path))
 # _copy_files_from_array([{"src_path": src, "dst_path": dst}])
